==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/ClusterRoleFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.rbac.AggregationRule;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterRoleFluent<A extends io.fabric8.openshift.api.model.ClusterRoleFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public io.fabric8.kubernetes.api.model.rbac.AggregationRule getAggregationRule();
  public A withAggregationRule(io.fabric8.kubernetes.api.model.rbac.AggregationRule aggregationRule);
  public java.lang.Boolean hasAggregationRule();
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public A addToRules(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public A setToRules(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public A addToRules(io.fabric8.openshift.api.model.PolicyRule... items);
  public A addAllToRules(java.util.Collection<io.fabric8.openshift.api.model.PolicyRule> items);
  public A removeFromRules(io.fabric8.openshift.api.model.PolicyRule... items);
  public A removeAllFromRules(java.util.Collection<io.fabric8.openshift.api.model.PolicyRule> items);
  public A removeMatchingFromRules(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.PolicyRule> getRules();
  public java.util.List<io.fabric8.openshift.api.model.PolicyRule> buildRules();
  public io.fabric8.openshift.api.model.PolicyRule buildRule(java.lang.Integer index);
  public io.fabric8.openshift.api.model.PolicyRule buildFirstRule();
  public io.fabric8.openshift.api.model.PolicyRule buildLastRule();
  public io.fabric8.openshift.api.model.PolicyRule buildMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public A withRules(java.util.List<io.fabric8.openshift.api.model.PolicyRule> rules);
  public A withRules(io.fabric8.openshift.api.model.PolicyRule... rules);
  public java.lang.Boolean hasRules();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> addNewRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> addNewRuleLike(io.fabric8.openshift.api.model.PolicyRule item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> setNewRuleLike(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editRule(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editFirstRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editLastRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PolicyRuleFluent<io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ClusterRoleFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.rbac.AggregationRule;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ClusterRoleFluent<A extends io.fabric8.openshift.api.model.ClusterRoleFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public io.fabric8.kubernetes.api.model.rbac.AggregationRule getAggregationRule();
  public A withAggregationRule(io.fabric8.kubernetes.api.model.rbac.AggregationRule aggregationRule);
  public java.lang.Boolean hasAggregationRule();
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public A addToRules(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public A setToRules(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public A addToRules(io.fabric8.openshift.api.model.PolicyRule... items);
  public A addAllToRules(java.util.Collection<io.fabric8.openshift.api.model.PolicyRule> items);
  public A removeFromRules(io.fabric8.openshift.api.model.PolicyRule... items);
  public A removeAllFromRules(java.util.Collection<io.fabric8.openshift.api.model.PolicyRule> items);
  public A removeMatchingFromRules(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.PolicyRule> getRules();
  public java.util.List<io.fabric8.openshift.api.model.PolicyRule> buildRules();
  public io.fabric8.openshift.api.model.PolicyRule buildRule(java.lang.Integer index);
  public io.fabric8.openshift.api.model.PolicyRule buildFirstRule();
  public io.fabric8.openshift.api.model.PolicyRule buildLastRule();
  public io.fabric8.openshift.api.model.PolicyRule buildMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public A withRules(java.util.List<io.fabric8.openshift.api.model.PolicyRule> rules);
  public A withRules(io.fabric8.openshift.api.model.PolicyRule... rules);
  public java.lang.Boolean hasRules();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> addNewRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> addNewRuleLike(io.fabric8.openshift.api.model.PolicyRule item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> setNewRuleLike(java.lang.Integer index,io.fabric8.openshift.api.model.PolicyRule item);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editRule(java.lang.Integer index);
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editFirstRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editLastRule();
  public io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<A> editMatchingRule(java.util.function.Predicate<io.fabric8.openshift.api.model.PolicyRuleBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ClusterRoleFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.PolicyRuleFluent<io.fabric8.openshift.api.model.ClusterRoleFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  
}
